==> mx-packageinstaller-pkglist_19.09.01.tar.xz: mx-packageinstaller-pkglist/ksnip.pm <==
<?xml version="1.0"?>
<app>


<category>
Screenshot Utilities
</category>

<name>
ksnip
</name>

<description>
   <am>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</am>
   <ar>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</ar>
   <bg>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</bg>
   <ca>Eina de captures de pantalla basada en Qt (no KDE) inspirada per Windows Snipping Tools</ca>
   <cs>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</cs>
   <da>Qt-baseret (ikke kde) skærmbilledværktøj som er inspireret af Windows Snipping-værktøjer</da>
   <de>Qt (nicht KDE)-basiertes Screenshot-Tool inspiriert von den Windows Snipping Tools</de>
   <el>Εργαλείο στιγμιότυπου Qt (όχι kde) εμπνευσμένο από τα Windows Snipping Tools</el>
   <en>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</en>
   <es>Herramienta de captura de pantalla inspirada en Windows Snipping Tools. Basado en Qt (no kde)</es>
   <et>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</et>
   <eu>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</eu>
   <fa>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</fa>
   <fi>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</fi>
   <fr>Outil de capture d'écran Qt (non kde) inspiré des utilitaires de découpage Windows</fr>
   <he_IL>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</he_IL>
   <hi>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</hi>
   <hr>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</hr>
   <hu>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</hu>
   <id>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</id>
   <is>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</is>
   <it>Strumento di cattura dello schermo basato sulle librerie Qt (non kde) simile a Snipping Tools</it>
   <ja_JP>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</ja_JP>
   <ja>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</ja>
   <kk>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</kk>
   <ko>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</ko>
   <lt>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</lt>
   <mk>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</mk>
   <nb>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</nb>
   <nl>Qt (niet kde) -gebaseerd gereedschap voor screenshots geïnspireerd op de Windows Snipping Tools</nl>
   <pl>Oparte na Qt (nie KDE) narzędzie do zrzutu ekranu zainspirowane Windows Snipping Tools</pl>
   <pt_BR>Ferramenta de captação de ecrã baseada em Qt (não kde) inspirada no Windows Snipping Tools</pt_BR>
   <pt>Ferramenta de captação de ecrã baseada em Qt (não kde) inspirada no Windows Snipping Tools</pt>
   <ro>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</ro>
   <ru>Утилита захвата снимков экрана наподобие Windows Snipping Tools</ru>
   <sk>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</sk>
   <sl>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</sl>
   <sq>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</sq>
   <sr>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</sr>
   <sv>Qt (inte kde) -baserat skärmdumpsverktyg inspirerat av Windows Skärmklippsverktyg</sv>
   <tr>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</tr>
   <uk>базова Qt(але не kde)-програма для створення знімків екрану натхненна Windows Snipping Tools</uk>
   <zh_CN>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</zh_CN>
   <zh_TW>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://a.fsdn.com/con/app/proj/ksnip/screenshots/32b0eaefbc23f9053d9f2f68065fc2bcbb93.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
ksnip
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
ksnip
</uninstall_package_names>

</app>

==> mx-packageinstaller-pkglist_19.12.04.tar.xz: mx-packageinstaller-pkglist/ksnip.pm <==
<?xml version="1.0"?>
<app>


<category>
Screenshot Utilities
</category>

<name>
ksnip
</name>

<description>
   <am>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</am>
   <ar>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</ar>
   <bg>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</bg>
   <bn>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</bn>
   <ca>Eina de captures de pantalla basada en Qt (no KDE) inspirada per Windows Snipping Tools</ca>
   <cs>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</cs>
   <da>Qt-baseret (ikke kde) skærmbilledværktøj som er inspireret af Windows Snipping-værktøjer</da>
   <de>Qt (nicht KDE)-basiertes Screenshot-Tool inspiriert von den Windows Snipping Tools</de>
   <el>Εργαλείο στιγμιότυπου Qt (όχι kde) εμπνευσμένο από τα Windows Snipping Tools</el>
   <en>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</en>
   <es>Herramienta de captura de pantalla inspirada en Windows Snipping Tools. Basado en Qt (no kde)</es>
   <et>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</et>
   <eu>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</eu>
   <fa>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</fa>
   <fil_PH>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</fil_PH>
   <fi>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</fi>
   <fr>Outil de capture d'écran Qt (non kde) inspiré des utilitaires de découpage Windows</fr>
   <he_IL>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</he_IL>
   <hi>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</hi>
   <hr>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</hr>
   <hu>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</hu>
   <id>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</id>
   <is>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</is>
   <it>Strumento di cattura dello schermo basato sulle librerie Qt (non kde) simile a Snipping Tools</it>
   <ja_JP>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</ja_JP>
   <ja>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</ja>
   <kk>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</kk>
   <ko>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</ko>
   <lt>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</lt>
   <mk>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</mk>
   <mr>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</mr>
   <nb>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</nb>
   <nl>Qt (niet kde) -gebaseerd gereedschap voor screenshots geïnspireerd op de Windows Snipping Tools</nl>
   <pl>Oparte na Qt (nie KDE) narzędzie do zrzutu ekranu zainspirowane Windows Snipping Tools</pl>
   <pt_BR>Ferramenta de captação de ecrã baseada em Qt (não kde) inspirada no Windows Snipping Tools</pt_BR>
   <pt>Ferramenta de captação de ecrã baseada em Qt (não kde) inspirada no Windows Snipping Tools</pt>
   <ro>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</ro>
   <ru>Утилита захвата снимков экрана наподобие Windows Snipping Tools</ru>
   <sk>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</sk>
   <sl>Qt (ne KDE) orodje za zajemanje zaslona, ki išče navdih v Windows Snipping Tools</sl>
   <sq>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</sq>
   <sr>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</sr>
   <sv>Qt (inte kde) -baserat skärmdumpsverktyg inspirerat av Windows Skärmklippsverktyg</sv>
   <tr>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</tr>
   <uk>базова Qt(але не kde)-програма для створення знімків екрану натхненна Windows Snipping Tools</uk>
   <vi>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</vi>
   <zh_CN>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</zh_CN>
   <zh_TW>Qt (not kde) -based screenshot tool inspired by the Windows Snipping Tools</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://a.fsdn.com/con/app/proj/ksnip/screenshots/32b0eaefbc23f9053d9f2f68065fc2bcbb93.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
ksnip
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
ksnip
</uninstall_package_names>

</app>
